@@ -100,6 +100,8 @@ KCalculator::KCalculator(QWidget *parent) :
 	base_choose_group_->addButton(binRadio, BinMode);
 	connect(base_choose_group_, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &KCalculator::slotBaseSelected);
 
+	base_conversion_labels_ = { binDisplay, hexDisplay, decDisplay, octDisplay };
+
 	angle_choose_group_ =  new QButtonGroup(this);
 	angle_choose_group_->setExclusive(true);
 	angle_choose_group_->addButton(degRadio, DegMode);
@@ -1622,7 +1624,7 @@ void KCalculator::showSettings() {
 
 	// color settings
     Colors *const color = new Colors(nullptr);
-	dialog->addPage(color, i18n("Colors"), QStringLiteral("format-fill-color"), i18n("Button & Display Colors"));
+	dialog->addPage(color, i18n("Colors"), QStringLiteral("preferences-desktop-color"), i18n("Button & Display Colors"));
 
 	// constant settings
 	if (!constants_) {
@@ -1869,6 +1871,19 @@ void KCalculator::slotSetNumeralMode() {
 	KCalcSettings::setCalculatorMode(KCalcSettings::EnumCalculatorMode::numeral);
 }
 
+//------------------------------------------------------------------------------
+// Name: slotBaseModeAmountChanged
+// Desc: updates numerical base conversions
+//------------------------------------------------------------------------------
+void KCalculator::slotBaseModeAmountChanged(KNumber number) {
+	quint64 n = number.toUint64();
+
+	decDisplay->setText(QString::number(n, 10));
+	binDisplay->setText(QString::number(n, 2));
+	octDisplay->setText(QString::number(n, 8));
+	hexDisplay->setText(QString::number(n, 16).toUpper());
+}
+
 //------------------------------------------------------------------------------
 // Name: showMemButtons
 // Desc: hides or shows the memory buttons
@@ -1960,6 +1975,11 @@ void KCalculator::showLogicButtons(bool toggled) {
 			btn->show();
 		}
 
+		for (QLabel* lbl : base_conversion_labels_) {
+			lbl->show();
+		}
+		connect(calc_display, &KCalcDisplay::changedAmount, this, &KCalculator::slotBaseModeAmountChanged);
+
 		for (int i = 10; i < 16; ++i) {
 			(num_button_group_->button(i))->show();
 		}
@@ -1979,6 +1999,11 @@ void KCalculator::showLogicButtons(bool toggled) {
 			btn->hide();
 		}
 
+		for (QLabel* lbl : base_conversion_labels_) {
+			lbl->hide();
+		}
+		connect(calc_display, &KCalcDisplay::changedAmount, this, &KCalculator::slotBaseModeAmountChanged);
+
 		statusBar()->setBaseIndicatorVisible(false);
 		calc_display->setStatusText(BaseField, QString());
 		for (int i = 10; i < 16; ++i) {
